<?php

// Attachment
// 
/**
 * Fields for the instance are stored in an array. Each field consists of
 * an array with three required keys: name, type, label
 * and one optional key: meta
 *
 * name    - (string) The field name used. No special characters.
 * type    - (string) The registered field type.
 *                  Fields available: text, textarea, wysiwyg, select
 * label   - (string) The label displayed for the field.
 * default - (string) The default WordPress metadata to use when initially adding the Attachment
 *                  Defaults available: title, caption, alt, description
 * meta    - (array) The field-specific parameters that apply only to that field type
 */

add_filter( 'attachments_default_instance', '__return_false' ); 

function gallery_attachments( $attachments )
{
  $fields         = array(
    array(
      'name'      => 'gallery_title',                         
      'type'      => 'text',                          
      'label'     => __( '제목', 'attachments' ),    
      'default'   => '제목',                         
    ),
    array(
      'name'      => 'gallery_caption',                       
      'type'      => 'text',                      
      'label'     => __( '캡션', 'attachments' ),  
      'default'   => '캡션',                       
    ),
  );

  $args = array(
    'label'         => '첨부',
    'post_type'     => array( 'post', 'page', 'movie', 'portfolio', 'gallery', 'team', 'slider', 'carousel' ),
    'position'      => 'advanced',
    'priority'      => 'high',
    'filetype'      => null,  
    'note'          => '여기에 파일을 첨부하세요!',
    'append'        => true,
    'button_text'   => __( '파일 첨부', 'attachments' ),
    'modal_text'    => __( '첨부', 'attachments' ),
    'router'        => 'browse',
    'post_parent'   => false,
    'fields'        => $fields,
  );
  $attachments->register( 'gallery_attachments', $args ); 
}

add_action( 'attachments_register', 'gallery_attachments' );



// function slider_attachments( $attachments )
// {
//   $fields         = array(
//     array(
//       'name'      => 'slider_title',                         // unique field name
//       'type'      => 'text',                          // registered field type
//       'label'     => __( '제목', 'attachments' ),    // label to display
//       'default'   => '제목',                         // default value upon selection
//     ),
//     array(
//       'name'      => 'slider_caption',                       // unique field name
//       'type'      => 'textarea',                      // registered field type
//       'label'     => __( '캡션', 'attachments' ),  // label to display
//       'default'   => '캡션',                       // default value upon selection
//     ),
// 	  array(
// 	    'name'      => 'slider_option',                            // unique field name
// 	    'type'      => 'select',                            // registered field type
// 	    'label'     => __( '옵션', 'attachments' ),       // label to display
// 	    'meta'      => array(                               // field-specific meta as defined by field class
// 	                    'allow_null'    => true,            // allow null value? (adds 'empty' <option>)
// 	                    'multiple'      => true,            // multiple <select>?
// 	                    'options'       => array(           // the <option>s to use
// 	                          '1'     => 'Option 1',
// 	                          '2'     => 'Option 2',
// 	                      )
// 	                  ),
// 	  ),
// 	  array(
// 	    'name'      => 'slider_description',                       // unique field name
// 	    'type'      => 'wysiwyg',                           // registered field type
// 	    'label'     => __( 'Description', 'attachments' ),  // label to display
// 	    'default'   => 'description',                       // default value upon selection
// 	  ),
// 	);

//   $args = array(

//     // title of the meta box (string)
//     'label'         => '첨부',

//     // all post types to utilize (string|array)
//     'post_type'     => array( 'slider' ),

//     // meta box position (string) (normal, side or advanced)
//     'position'      => 'advanced',

//     // meta box priority (string) (high, default, low, core)
//     'priority'      => 'high',

//     // allowed file type(s) (array) (image|video|text|audio|application)
//     'filetype'      => null,  // no filetype limit

//     // include a note within the meta box (string)
//     'note'          => '여기에 파일을 첨부하세요!',

//     // by default new Attachments will be appended to the list
//     // but you can have then prepend if you set this to false
//     'append'        => true,

//     // text for 'Attach' button in meta box (string)
//     'button_text'   => __( '파일 첨부', 'attachments' ),

//     // text for modal 'Attach' button (string)
//     'modal_text'    => __( '첨부', 'attachments' ),

//     // which tab should be the default in the modal (string) (browse|upload)
//     'router'        => 'browse',

//     // whether Attachments should set 'Uploaded to' (if not already set)
//     'post_parent'   => false,

//     // fields array
//     'fields'        => $fields,

//   );

//   $attachments->register( 'slider_attachments', $args ); // unique instance name
// }

// add_action( 'attachments_register', 'slider_attachments' );